ResourceFork

Struct ResourceFork 

pub struct ResourceFork<'a> { /* private fields */ }
A Handle to a Resource Fork

A Resource Fork is a macos specific file attribute that contains arbitrary binary data.

Implementations

Source

impl<'a> ResourceFork<'a>

pub fn new(file: &'a File) -> Self

Create a new Resource Fork handle

Note that if the file does not already have a resource fork, it will only be created when the first write is performed.

pub fn position(&self) -> u32

Returns the current position of the resource fork

pub fn set_position(&mut self, position: u32)

Seek to a new position in the resource fork infallibly

pub fn delete(&mut self) -> Result<()>

Remove the resource fork from the file

This will remove any existing resource fork

Note that this does not reset the current offset, it may be desired to seek to the beginning of the resource fork after calling this, if you wish to continue writing to the resource fork