pub struct ReferenceListItem {
pub resource_id: i16,
pub resource_name_offset: i16,
pub attributes: u8,
pub resource_data_offset: u32,
pub reserved_handle: u32,
}Fields
resource_id: i16Resource ID
resource_name_offset: i16Offset from beginning of resource name list to resource name
attributes: u8Resource attributes
resource_data_offset: u32Offset from beginning of resource data to data of this resource
reserved_handle: u32Reserved for handle to resource