pub struct ResourceHeader {
pub resource_data_offset: u32,
pub resource_map_offset: u32,
pub resource_data_len: u32,
pub resource_map_len: u32,
}Fields
resource_data_offset: u32Offset from beginning of resource fork to resource data
resource_map_offset: u32Offset from beginning of resource fork to resource map
resource_data_len: u32Length of resource data
resource_map_len: u32Length of resource map