pub struct ResourceMap {
pub reserved_header: [u8; 16],
pub reserved_handle: u32,
pub reserved_file_reference: u16,
pub attributes: u16,
pub type_list_offset: u16,
pub name_list_offset: u16,
pub last_type_index: u16,
}Fields
reserved_header: [u8; 16]Reserved for copy of resource header
reserved_handle: u32Reserved for handle to next resource map
reserved_file_reference: u16Reserved for file reference number
attributes: u16type_list_offset: u16Offset from beginning of map to resource type list
name_list_offset: u16Offset from beginning of map to resource name list
last_type_index: u16Number of types in the map minus 1