pub struct TypeMapItem {
pub resource_type: FourCC,
pub last_resource_index: u16,
pub reference_list_offset: u16,
}Fields
resource_type: FourCCResource type
last_resource_index: u16Number of resources of this type in map minus 1
reference_list_offset: u16Offset from beginning of resource type list to reference list of this type